Module: Google::Cloud::CloudQuotas
- Defined in:
- lib/google/cloud/cloud_quotas.rb,
lib/google/cloud/cloud_quotas/version.rb
Constant Summary collapse
- VERSION =
"2.2.0"
Class Method Summary collapse
-
.cloud_quotas(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudQuotas.
-
.cloud_quotas_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudQuotas service is supported by the current client.
-
.configure {|::Google::Cloud.configure.cloud_quotas| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_quotas library.
Class Method Details
.cloud_quotas(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudQuotas.
By default, this returns an instance of
Google::Cloud::CloudQuotas::V1::CloudQuotas::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CloudQuotas service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CloudQuotas service. You can determine whether the method will succeed by calling cloud_quotas_available?.
About CloudQuotas
The Cloud Quotas API is an infrastructure service for Google Cloud that lets service consumers list and manage their resource usage limits.
- List/Get the metadata and current status of the quotas for a service.
- Create/Update quota preferencess that declare the preferred quota values.
- Check the status of a quota preference request.
- List/Get pending and historical quota preference.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/google/cloud/cloud_quotas.rb', line 81 def self.cloud_quotas version: :v1, transport: :grpc, &block require "google/cloud/cloud_quotas/#{version.to_s.downcase}" package_name = Google::Cloud::CloudQuotas .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::CloudQuotas.const_get(package_name).const_get(:CloudQuotas) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.cloud_quotas_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudQuotas service is supported by the current client. If true, you can retrieve a client object by calling cloud_quotas. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CloudQuotas service, or if the versioned client gem needs an update to support the CloudQuotas service.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/google/cloud/cloud_quotas.rb', line 105 def self.cloud_quotas_available? version: :v1, transport: :grpc require "google/cloud/cloud_quotas/#{version.to_s.downcase}" package_name = Google::Cloud::CloudQuotas .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::CloudQuotas.const_get package_name return false unless service_module.const_defined? :CloudQuotas service_module = service_module.const_get :CloudQuotas if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.cloud_quotas| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-cloud_quotas library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
153 154 155 156 157 |
# File 'lib/google/cloud/cloud_quotas.rb', line 153 def self.configure yield ::Google::Cloud.configure.cloud_quotas if block_given? ::Google::Cloud.configure.cloud_quotas end |